@@ -14,10 +14,10 @@ from refurb.error import Error
 @dataclass
 class ErrorInfo(Error):
     """
-    Often times generator and comprehension expressions can be written more
-    succinctly. For example, passing a list comprehension to a function when
-    a generator expression would suffice, or using the shorthand notation
-    in the case of `list` and `set`. For example:
+    Often times generator expressions and list/set/dict comprehensions can be
+    written more succinctly. For example, passing a list comprehension to a
+    function when a generator expression would suffice, or using the shorthand
+    notation in the case of `list` and `set`. For example:
 
     Bad:
 
@@ -71,16 +71,9 @@ def check(node: CallExpr, errors: list[Error]) -> None:
     match node:
         case CallExpr(
             callee=NameExpr(name=name, fullname=fullname),
-            args=[
-                GeneratorExpr()
-                | ListComprehension()
-                | SetComprehension() as arg
-            ],
+            args=[GeneratorExpr() | ListComprehension() | SetComprehension() as arg],
         ) if fullname in FUNCTION_MAPPINGS:
-            if (
-                isinstance(arg, GeneratorExpr)
-                and name not in COMPREHENSION_SHORTHAND_TYPES
-            ):
+            if isinstance(arg, GeneratorExpr) and name not in COMPREHENSION_SHORTHAND_TYPES:
                 return
 
             if isinstance(arg, SetComprehension) and name not in SET_TYPES:
@@ -89,8 +82,4 @@ def check(node: CallExpr, errors: list[Error]) -> None:
             old = format_func_name(NODE_TYPE_TO_FUNC_NAME[type(arg)])
             new = format_func_name(fullname)
 
-            errors.append(
-                ErrorInfo.from_node(
-                    node, f"Replace `{name}({old})` with `{new}`"
-                )
-            )
+            errors.append(ErrorInfo.from_node(node, f"Replace `{name}({old})` with `{new}`"))
