@@ -3,6 +3,7 @@ from itertools import chain, combinations, starmap
 
 from mypy.nodes import (
     Block,
+    BytesExpr,
     CallExpr,
     ComparisonExpr,
     DictExpr,
@@ -11,6 +12,7 @@ from mypy.nodes import (
     ForStmt,
     GeneratorExpr,
     IndexExpr,
+    IntExpr,
     ListExpr,
     MemberExpr,
     MypyFile,
@@ -24,14 +26,12 @@ from mypy.nodes import (
     TupleExpr,
     UnaryExpr,
 )
-from mypy.traverser import TraverserVisitor
 
 from refurb.error import Error
+from refurb.visitor import TraverserVisitor
 
 
-def extract_binary_oper(
-    oper: str, node: OpExpr
-) -> tuple[Expression, Expression] | None:
+def extract_binary_oper(oper: str, node: OpExpr) -> tuple[Expression, Expression] | None:
     match node:
         case OpExpr(
             op=op,
@@ -118,9 +118,7 @@ def is_equivalent(lhs: Node | None, rhs: Node | None) -> bool:
             )
 
         case IndexExpr() as lhs, IndexExpr() as rhs:
-            return is_equivalent(lhs.base, rhs.base) and is_equivalent(
-                lhs.index, rhs.index
-            )
+            return is_equivalent(lhs.base, rhs.base) and is_equivalent(lhs.index, rhs.index)
 
         case CallExpr() as lhs, CallExpr() as rhs:
             return (
@@ -136,15 +134,12 @@ def is_equivalent(lhs: Node | None, rhs: Node | None) -> bool:
             | (SetExpr() as lhs, SetExpr() as rhs)
         ):
             return len(lhs.items) == len(rhs.items) and all(  # type: ignore
-                starmap(
-                    is_equivalent, zip(lhs.items, rhs.items)  # type: ignore
-                )
+                starmap(is_equivalent, zip(lhs.items, rhs.items))  # type: ignore
             )
 
         case DictExpr() as lhs, DictExpr() as rhs:
             return len(lhs.items) == len(rhs.items) and all(
-                is_equivalent(lhs_item[0], rhs_item[0])
-                and is_equivalent(lhs_item[1], rhs_item[1])
+                is_equivalent(lhs_item[0], rhs_item[0]) and is_equivalent(lhs_item[1], rhs_item[1])
                 for lhs_item, rhs_item in zip(lhs.items, rhs.items)
             )
 
@@ -209,8 +204,7 @@ def get_common_expr_in_comparison_chain(
             ComparisonExpr(operators=[lhs_oper], operands=[a, b]),
             ComparisonExpr(operators=[rhs_oper], operands=[c, d]),
         ) if (
-            lhs_oper == rhs_oper == cmp_oper
-            and (indices := get_common_expr_positions(a, b, c, d))
+            lhs_oper == rhs_oper == cmp_oper and (indices := get_common_expr_positions(a, b, c, d))
         ):
             return a, indices
 
@@ -244,7 +238,7 @@ def is_name_unused_in_contexts(name: NameExpr, contexts: list[Node]) -> bool:
 
     for ctx in contexts:
         visitor = ReadCountVisitor(name)
-        ctx.accept(visitor)
+        visitor.accept(ctx)
 
         if visitor.was_read:
             return False
@@ -291,4 +285,19 @@ def stringify(node: Node) -> str:
         case NameExpr(name=name):
             return name
 
-    return str(node)  # pragma: no cover
+        case BytesExpr(value=value):
+            # TODO: use same formatting as source line
+            return repr(value.encode())
+
+        case IntExpr(value=value):
+            # TODO: use same formatting as source line
+            return str(value)
+
+        case CallExpr():
+            name = stringify(node.callee)
+
+            args = ", ".join(stringify(arg) for arg in node.args)
+
+            return f"{name}({args})"
+
+    return "x"  # pragma: no cover
