@@ -76,10 +76,7 @@ def get_trailing_return(node: Statement) -> Generator[Statement, None, None]:
 
                 yield from get_trailing_return(body.body[-1])
 
-        case (
-            IfStmt(else_body=Block(body=[*_, stmt]))
-            | WithStmt(body=Block(body=[*_, stmt]))
-        ):
+        case (IfStmt(else_body=Block(body=[*_, stmt])) | WithStmt(body=Block(body=[*_, stmt]))):
             yield from get_trailing_return(stmt)
 
     return None
@@ -91,6 +88,4 @@ def check(node: FuncItem, errors: list[Error]) -> None:
             if not prev and isinstance(stmt, ReturnStmt):
                 return
 
-            errors.extend(
-                ErrorInfo.from_node(x) for x in get_trailing_return(stmt)
-            )
+            errors.extend(ErrorInfo.from_node(x) for x in get_trailing_return(stmt))
