@@ -58,7 +58,7 @@ class ErrorInfo(Error):
 
     name = "simplify-return"
     code = 126
-    categories = ["control-flow", "readability"]
+    categories = ("control-flow", "readability")
 
 
 def get_trailing_return(node: Statement) -> Statement | None:
@@ -72,9 +72,7 @@ def get_trailing_return(node: Statement) -> Statement | None:
         ) if all(isinstance(block.body[-1], ReturnStmt) for block in bodies):
             return get_trailing_return(stmt)
 
-        case IfStmt(
-            body=[Block(body=[*_, ReturnStmt()])], else_body=Block(body=[stmt])
-        ):
+        case IfStmt(body=[Block(body=[*_, ReturnStmt()])], else_body=Block(body=[stmt])):
             return get_trailing_return(stmt)
 
     return None
