@@ -40,17 +40,15 @@ class ErrorInfo(Error):
     name = "simplify-readlines"
     code = 129
     msg: str = "Replace `f.readlines()` with `f`"
-    categories = ["builtin", "readability"]
+    categories = ("builtin", "readability")
 
 
 def get_readline_file_object(expr: Expression) -> NameExpr | None:
     match expr:
         case CallExpr(
-            callee=MemberExpr(
-                expr=NameExpr(node=Var(type=ty)) as f, name="readlines"
-            ),
+            callee=MemberExpr(expr=NameExpr(node=Var(type=ty)) as f, name="readlines"),
             args=[],
-        ) if str(ty) in ("io.TextIOWrapper", "io.BufferedReader"):
+        ) if str(ty) in {"io.TextIOWrapper", "io.BufferedReader"}:
             return f
 
     return None
@@ -62,6 +60,8 @@ def check(node: ForStmt | GeneratorExpr, errors: list[Error]) -> None:
             errors.append(ErrorInfo.from_node(f))
 
     else:
-        for expr in node.sequences:
-            if f := get_readline_file_object(expr):
-                errors.append(ErrorInfo.from_node(f))
+        errors.extend(
+            ErrorInfo.from_node(f)
+            for expr in node.sequences
+            if (f := get_readline_file_object(expr))
+        )
