@@ -19,7 +19,7 @@ class ErrorInfo(Error):
     """
     A common operation is changing the extension of a file. If you have an
     existing `Path` object, you don't need to convert it to a string, slice
-    it, and append a new extension. Instead, use the `with_suffix()` function:
+    it, and append a new extension. Instead, use the `with_suffix()` method:
 
     Bad:
 
@@ -36,8 +36,8 @@ class ErrorInfo(Error):
 
     name = "use-pathlib-with-suffix"
     code = 100
-    msg: str = "Use `Path(x).with_suffix(y)` instead of slice and concat"  # noqa: E501
-    categories = ["pathlib"]
+    msg: str = "Use `Path(x).with_suffix(y)` instead of slice and concat"
+    categories = ("pathlib",)
 
 
 def check(node: OpExpr, errors: list[Error]) -> None:
